@@ -19,38 +19,39 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 #include <locale.h>
 
 #include <libgda/libgda.h>
-#include "gnome-db-intl.h"
-#include "components-browser.h"
+#include <libgnomedb/libgnomedb.h>
+#include <bonobo/bonobo-generic-factory.h>
+#include <bonobo/bonobo-i18n.h>
+#include "components-connection.h"
+#include "components-database.h"
+#include "components-database-config.h"
 #include "components-manager.h"
-#include "components-sql.h"
-
-static GdaServer *component_factory = NULL;
 
 static void initialize_component_factory (gpointer user_data);
 
+static gint objects_loaded = 0;
+
 int
 main (int argc, char *argv[])
 {
-
-#ifdef ENABLE_NLS
 	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GNOMEDB_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
-#endif
 
 	/* initialize application */
-	gnome_db_init ("gnomedb-components", VERSION, argc, argv);
+	gnome_db_init ("gnome-db-components", VERSION, argc, argv);
 
 	/* run application */
 	gnome_db_main_run ((GdaInitFunc) initialize_component_factory, NULL);
 
+	/* free all resources */
+	components_connection_close_all ();
+
 	return 0;
 }
 
@@ -59,16 +60,32 @@ main (int argc, char *argv[])
  */
 
 static void
-last_client_gone_cb (GdaServer *server, gpointer user_data)
+object_destroyed_cb (GObject *object, gpointer user_data)
 {
-	gda_log_message (_("No more clients. Terminating..."));
-	gnome_db_main_quit ();
+	objects_loaded--;
+	if (objects_loaded == 0)
+		gnome_db_main_quit ();
 }
 
-static void
-last_component_unregistered_cb (GdaServer *server, gpointer user_data)
+static BonoboObject *
+factory_callback (BonoboGenericFactory *factory, const gchar *id, gpointer closure)
 {
-	gda_log_message (_("All components have been unregistered!! This shouldn't happen"));
+	BonoboObject *object = NULL;
+
+	if (!strcmp (id, GNOME_DB_ID_DATABASE))
+		object = g_object_new (COMPONENTS_TYPE_DATABASE, NULL);
+	else if (!strcmp (id, GNOME_DB_ID_DATABASE_CONFIG))
+		object = g_object_new (COMPONENTS_TYPE_DATABASE_CONFIG, NULL);
+	else if (!strcmp (id, GNOME_DB_ID_MANAGER))
+		object = g_object_new (COMPONENTS_TYPE_MANAGER, NULL);
+
+	if (BONOBO_IS_OBJECT (object)) {
+		objects_loaded++;
+		g_signal_connect (G_OBJECT (object), "destroy",
+				  G_CALLBACK (object_destroyed_cb), NULL);
+	}
+
+	return object;
 }
 
 /*
@@ -78,23 +95,14 @@ last_component_unregistered_cb (GdaServer *server, gpointer user_data)
 static void
 initialize_component_factory (gpointer user_data)
 {
-	component_factory = gda_server_new ("OAFIID:GNOME_Database_UIComponentFactory");
+	BonoboGenericFactory *component_factory;
 
-	g_signal_connect (G_OBJECT (component_factory), "last_component_unregistered",
-			  G_CALLBACK (last_component_unregistered_cb), NULL);
-	g_signal_connect (G_OBJECT (component_factory), "last_client_gone",
-			  G_CALLBACK (last_client_gone_cb), NULL);
-
-	gda_server_register_component (component_factory,
-				       GNOME_DB_ID_BROWSER,
-				       COMPONENTS_TYPE_BROWSER);
-	gda_server_register_component (component_factory,
-				       GNOME_DB_ID_SQL,
-				       COMPONENTS_TYPE_SQL);
-	gda_server_register_component (component_factory,
-				       GNOME_DB_ID_MANAGER,
-				       COMPONENTS_TYPE_MANAGER);
-	/*gda_server_register_component (component_factory,
-	                               GNOME_DB_ID_EXPORT,
-				       components_export_get_type ());*/
+	component_factory = bonobo_generic_factory_main (
+		"OAFIID:GNOME_Database_UIComponentFactory",
+		factory_callback,
+		NULL);
+	if (!component_factory) {
+		gnome_db_main_quit ();
+		return;
+	}
 }
