@@ -21,6 +21,7 @@
  */
 
 #include <bonobo/bonobo-exception.h>
+#include <bonobo/bonobo-widget.h>
 #include <libgnomedb/gnome-db-window.h>
 #include "gnome-db-shell-component-client.h"
 
@@ -153,6 +154,51 @@ gnome_db_shell_component_client_new (GnomeDbShell *shell, const gchar *iid)
  * Returns: a newly allocated string that contains the version number.
  */
 gchar *
-gnome_db_shell_component_client_get_version (GnomeDbShellComponentClient *wid)
+gnome_db_shell_component_client_get_version (GnomeDbShellComponentClient *client)
 {
+	CORBA_Environment ev;
+	CORBA_char *corba_version;
+	gchar *version;
+
+	g_return_val_if_fail (GNOME_DB_IS_SHELL_COMPONENT_CLIENT (client), NULL);
+
+	CORBA_exception_init (&ev);
+	corba_version = GNOME_Database_UIShellComponent_getVersion (
+		client->priv->corba_shell_comp, &ev);
+	if (BONOBO_EX (&ev)) {
+		CORBA_exception_free (&ev);
+		return NULL;
+	}
+
+	CORBA_exception_free (&ev);
+
+	version = g_strdup (corba_version);
+	CORBA_free (corba_version);
+
+	return version;
+}
+
+/**
+ * gnome_db_shell_component_client_get_config_control
+ */
+GnomeDbControlWidget *
+gnome_db_shell_component_client_get_config_control (GnomeDbShellComponentClient *client)
+{
+	Bonobo_Control corba_control;
+	CORBA_Environment ev;
+
+	g_return_val_if_fail (GNOME_DB_IS_SHELL_COMPONENT_CLIENT (client), NULL);
+
+	CORBA_exception_init (&ev);
+	corba_control = GNOME_Database_UIShellComponent_getConfigControl (
+		client->priv->corba_shell_comp, &ev);
+	if (BONOBO_EX (&ev) || !corba_control) {
+		CORBA_exception_free (&ev);
+		return NULL;
+	}
+
+	return GNOME_DB_CONTROL_WIDGET (
+		gnome_db_control_widget_new_from_corba (
+			corba_control,
+			gnome_db_control_widget_get_ui_container (GNOME_DB_CONTROL_WIDGET (client))));
 }
