@@ -21,6 +21,7 @@
  */
 
 #include <config.h>
+#include <libgda/gda-log.h>
 #include <gtk/gtksignal.h>
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-i18n.h>
@@ -73,21 +74,16 @@ impl_UIShellComponent_addClient (PortableServer_Servant servant,
 				 CORBA_Environment *ev)
 {
 	GNOME_Database_UIShell shell_copy;
-	CORBA_Environment ev2;
 	GnomeDbShellComponent *comp = (GnomeDbShellComponent *) bonobo_object (servant);
 
 	g_return_if_fail (GNOME_DB_IS_SHELL_COMPONENT (comp));
 
-	CORBA_exception_init (&ev2);
-	shell_copy = CORBA_Object_duplicate (corba_shell, &ev2);
-	if (BONOBO_EX (&ev2)) {
+	shell_copy = CORBA_Object_duplicate (corba_shell, ev);
+	if (BONOBO_EX (ev)) {
 		gda_log_error (_("Could not duplicate UIShell object"));
-		CORBA_exception_free (&ev2);
 		return;
 	}
 
-	CORBA_exception_free (&ev2);
-
 	comp->priv->shell_clients = g_list_append (comp->priv->shell_clients, shell_copy);
 }
 
@@ -100,11 +96,28 @@ impl_UIShellComponent_selectConnection (PortableServer_Servant servant,
 {
 	GnomeDbShellComponent *comp = (GnomeDbShellComponent *) bonobo_object (servant);
 
-	g_return_val_if_fail (GNOME_DB_IS_SHELL_COMPONENT (comp), FALSE);
-
+	bonobo_return_val_if_fail (GNOME_DB_IS_SHELL_COMPONENT (comp), FALSE, ev);
 	return gnome_db_shell_component_select_connection (comp, name, username, password);
 }
 
+static Bonobo_Control
+impl_UIShellComponent_getConfigControl (PortableServer_Servant servant,
+					CORBA_Environment *ev)
+{
+	GnomeDbControl *control;
+	GnomeDbShellComponent *comp = (GnomeDbShellComponent *) bonobo_object (servant);
+
+	bonobo_return_val_if_fail (GNOME_DB_IS_SHELL_COMPONENT (comp), CORBA_OBJECT_NIL, ev);
+	
+	control = gnome_db_shell_component_get_config_control (comp);
+	if (!control) {
+		bonobo_exception_general_error_set (ev, NULL, _("Couldn't load config control"));
+		return CORBA_OBJECT_NIL;
+	}
+
+	return bonobo_object_corba_objref (BONOBO_OBJECT (control));
+}
+
 /*
  * GnomeDbShellComponent class implementation
  */
@@ -123,6 +136,7 @@ gnome_db_shell_component_class_init (GnomeDbShellComponentClass *klass)
 	epv->getVersion = impl_UIShellComponent_getVersion;
 	epv->addClient = impl_UIShellComponent_addClient;
 	epv->selectConnection = impl_UIShellComponent_selectConnection;
+	epv->getConfigControl = impl_UIShellComponent_getConfigControl;
 }
 
 static void
@@ -137,7 +151,6 @@ gnome_db_shell_component_init (GnomeDbShellComponent *comp,
 static void
 gnome_db_shell_component_finalize (GObject *object)
 {
-	GList *l;
 	CORBA_Environment ev;
 	GnomeDbShellComponent *comp = (GnomeDbShellComponent *) object;
 
@@ -158,9 +171,9 @@ gnome_db_shell_component_finalize (GObject *object)
 }
 
 BONOBO_TYPE_FUNC_FULL (GnomeDbShellComponent,
-			 GNOME_Database_UIShellComponent,
-			 PARENT_TYPE,
-			 gnome_db_shell_component)
+		       GNOME_Database_UIShellComponent,
+		       PARENT_TYPE,
+		       gnome_db_shell_component)
 
 /**
  * gnome_db_shell_component_construct
@@ -230,6 +243,18 @@ gnome_db_shell_component_select_connection (GnomeDbShellComponent *comp,
 	return CLASS (comp)->select_connection (comp, name, username, password);
 }
 
+/**
+ * gnome_db_shell_component_get_config_control
+ */
+GnomeDbControl *
+gnome_db_shell_component_get_config_control (GnomeDbShellComponent *comp)
+{
+	g_return_val_if_fail (GNOME_DB_IS_SHELL_COMPONENT (comp), NULL);
+	g_return_val_if_fail (CLASS (comp)->get_config_control != NULL, NULL);
+
+	return CLASS (comp)->get_config_control (comp);
+}
+
 /**
  * gnome_db_shell_component_notify_connection_opened
  */
