@@ -54,6 +54,7 @@ struct _GnomeDbShellComponentClass {
 					const gchar *name,
 					const gchar *username,
 					const gchar *password);
+	GnomeDbControl * (* get_config_control) (GnomeDbShellComponent *comp);
 };
 
 GType                  gnome_db_shell_component_get_type (void);
@@ -65,6 +66,7 @@ gboolean               gnome_db_shell_component_select_connection (GnomeDbShellC
 								   const gchar *name,
 								   const gchar *username,
 								   const gchar *password);
+GnomeDbControl        *gnome_db_shell_component_get_config_control (GnomeDbShellComponent *comp);
 
 /* notifications to clients */
 void gnome_db_shell_component_notify_connection_opened (GnomeDbShellComponent *comp,
