@@ -21,6 +21,7 @@
  */
 
 #include <config.h>
+#include <stdlib.h>
 #include <bonobo/bonobo-i18n.h>
 #include <libgda/gda-config.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -32,8 +33,11 @@
 #include <gtk/gtknotebook.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkvpaned.h>
+#include <libgnomedb/gnome-db-config.h>
 #include <libgnomedb/gnome-db-util.h>
 #include <libgnomedb/gnome-db-window.h>
+#include <libgnomeui/gnome-about.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include "gnome-db-defs.h"
 #include "gnome-db-shell.h"
 #include "gnome-db-shell-settings.h"
@@ -104,17 +108,17 @@ add_components_to_shortcut (GnomeDbShell *shell)
 
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 
-	components = gda_config_get_component_list (
+	components = gnome_db_config_get_component_list (
 		"repo_ids.has('IDL:GNOME/Database/UIShellComponent:1.0')");
 	if (components) {
 		GList *node;
-		GdaComponentInfo *comp_info;
+		GnomeDbComponentInfo *comp_info;
 		gchar *str;
           
 		for (node = g_list_first (components);
 		     node != NULL;
 		     node = g_list_next (node)) {
-			comp_info = (GdaComponentInfo *) node->data;
+			comp_info = (GnomeDbComponentInfo *) node->data;
 			str = g_strdup_printf ("%s/%s",
 					       GNOME_DB_SHELL_CONFIG_SECTION_LOAD,
 					       comp_info->id);
@@ -130,14 +134,14 @@ add_components_to_shortcut (GnomeDbShell *shell)
 					comp_info->description,
 					comp_info->id,
 					shell_icon,
-					GTK_SIGNAL_FUNC (shortcut_button_clicked_cb),
-					shell);
+					shortcut_button_clicked_cb,
+					(gpointer) shell);
 
 				g_free (shell_icon);
 			}
 			g_free (str);
 		}
-		gda_config_free_component_list (components);
+		gnome_db_config_free_component_list (components);
 	}
 
 	/* load the default component */
@@ -198,7 +202,7 @@ setup_window (GnomeDbShell *shell)
 	add_components_to_shortcut (shell);
 
 	/* load state of window from configuration */
-	uic = gnome_db_window_get_ui_component (shell->priv->window);
+	uic = gnome_db_window_get_ui_component (GNOME_DB_WINDOW (shell->priv->window));
 
 	if (gda_config_get_boolean (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT) ||
 	    !gda_config_has_key (GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT)) {
@@ -247,7 +251,7 @@ config_changed_cb (const gchar *path, gpointer user_data)
 	g_return_if_fail (path != NULL);
 	g_return_if_fail (GNOME_DB_IS_SHELL (shell));
 
-	uic = gnome_db_window_get_ui_component (shell->priv->window);
+	uic = gnome_db_window_get_ui_component (GNOME_DB_WINDOW (shell->priv->window));
 
 	if (!strcmp (path, GNOME_DB_SHELL_CONFIG_SHOW_SHORTCUT)) {
 		/* hide/show shortcut bar */
@@ -313,7 +317,7 @@ shortcut_button_clicked_cb (GnomeDbShortcut *shortcut,
 	/* load it */
 	wid = gnome_db_shell_component_client_new (shell, tooltip);
 	if (GNOME_DB_IS_SHELL_COMPONENT_CLIENT (wid)) {
-		gchar *title;
+		const gchar *title;
 
 		g_object_set_data_full (G_OBJECT (wid),
 			"GNOME_DB_Manager_ComponentDescription",
@@ -384,7 +388,8 @@ verb_HelpAbout (BonoboUIComponent *uic, void *user_data, const char *path)
                                   _("Copyright 2001, The GNOME Foundation"),
                                   _("GNOME Database front-end"),
                                   authors, NULL, NULL, logo);
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), shell->priv->window);
+	gtk_window_set_transient_for (GTK_WINDOW (dialog),
+				      GTK_WINDOW (shell->priv->window));
 	g_signal_connect (G_OBJECT (dialog), "destroy",
 			  G_CALLBACK (gtk_widget_destroyed), &dialog);
 
@@ -481,7 +486,8 @@ static void
 impl_UIShell_notifyConnectionOpened (PortableServer_Servant servant,
 				     const CORBA_char *name,
 				     const CORBA_char *username,
-				     const CORBA_char *password)
+				     const CORBA_char *password,
+				     CORBA_Environment *ev)
 {
 	GnomeDbShell *shell = (GnomeDbShell *) bonobo_object (servant);
 
@@ -492,7 +498,8 @@ static void
 impl_UIShell_notifyConnectionClosed (PortableServer_Servant servant,
 				     const CORBA_char *name,
 				     const CORBA_char *username,
-				     const CORBA_char *password)
+				     const CORBA_char *password,
+				     CORBA_Environment *ev)
 {
 	GnomeDbShell *shell = (GnomeDbShell *) bonobo_object (servant);
 
