@@ -19,8 +19,11 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <libgda/gda-error.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
+#include <bonobo/bonobo-exception.h>
+#include <bonobo/bonobo-i18n.h>
 #include "gnome-db-defs.h"
 #include "gnome-db-monikers.h"
 
@@ -43,7 +46,7 @@ moniker_database_resolve (BonoboMoniker *moniker,
 			  const CORBA_char *requested_interface,
 			  CORBA_Environment *ev)
 {
-	gchar *moniker_name;
+	const gchar *moniker_name;
 	GnomeVFSURI *uri;
 	Bonobo_Unknown unknown = CORBA_OBJECT_NIL;
 
